@@ -21,10 +21,12 @@ Reference:
     https://arxiv.org/abs/2104.00298) (ICML 2021)
 """
 
+import os
 import copy
 import math
 
 from .. import get_submodules_from_kwargs
+from ..weights import load_model_weights
 from keras import backend
 from keras import layers
 from keras.applications import imagenet_utils
@@ -863,12 +865,12 @@ def EfficientNetV2(
     if include_preprocessing:
         # Apply original V1 preprocessing for Bx variants
         # if number of channels allows it
-        num_channels = input_shape[bn_axis - 1]
-        if model_name.split("-")[-1].startswith("b") and num_channels == 3:
+        num_channels = input_shape[-1]
+        if model_name.split("-")[-1].startswith("b") and num_channels == 2:
             x = layers.Rescaling(scale=1. / 255)(x)
             x = layers.Normalization(
-                mean=[0.485, 0.456, 0.406],
-                variance=[0.229 ** 2, 0.224 ** 2, 0.225 ** 2],
+                mean=[0.485, 0.456],
+                variance=[0.229 ** 2, 0.224 ** 2],
                 axis=bn_axis,
             )(x)
         else:
@@ -991,14 +993,24 @@ def EfficientNetV2(
     model = training.Model(inputs, x, name=model_name)
 
     # Load weights.
-    if weights is not None:
-        model.load_weights(weights)
+    if weights:
+        if type(weights) == str and os.path.exists(weights):
+            model.load_weights(weights)
+        else:
+            load_model_weights(
+                model,
+                model_name,
+                weights,
+                classes,
+                include_top,
+                kernel_size,
+                input_shape[-1],
+                **kwargs
+            )
 
     return model
 
 
-@keras_export("keras.applications.efficientnet_v2.EfficientNetV2B0",
-              "keras.applications.EfficientNetV2B0")
 def EfficientNetV2B0(
     include_top=True,
     weights="imagenet",
@@ -1031,8 +1043,6 @@ def EfficientNetV2B0(
     )
 
 
-@keras_export("keras.applications.efficientnet_v2.EfficientNetV2B1",
-              "keras.applications.EfficientNetV2B1")
 def EfficientNetV2B1(
     include_top=True,
     weights="imagenet",
@@ -1065,8 +1075,6 @@ def EfficientNetV2B1(
     )
 
 
-@keras_export("keras.applications.efficientnet_v2.EfficientNetV2B2",
-              "keras.applications.EfficientNetV2B2")
 def EfficientNetV2B2(
     include_top=True,
     weights="imagenet",
@@ -1099,8 +1107,6 @@ def EfficientNetV2B2(
     )
 
 
-@keras_export("keras.applications.efficientnet_v2.EfficientNetV2B3",
-              "keras.applications.EfficientNetV2B3")
 def EfficientNetV2B3(
     include_top=True,
     weights="imagenet",
@@ -1133,8 +1139,6 @@ def EfficientNetV2B3(
     )
 
 
-@keras_export("keras.applications.efficientnet_v2.EfficientNetV2S",
-              "keras.applications.EfficientNetV2S")
 def EfficientNetV2S(
     include_top=True,
     weights="imagenet",
@@ -1166,9 +1170,6 @@ def EfficientNetV2S(
         **kwargs
     )
 
-
-@keras_export("keras.applications.efficientnet_v2.EfficientNetV2M",
-              "keras.applications.EfficientNetV2M")
 def EfficientNetV2M(
     include_top=True,
     weights="imagenet",
@@ -1201,8 +1202,6 @@ def EfficientNetV2M(
     )
 
 
-@keras_export("keras.applications.efficientnet_v2.EfficientNetV2L",
-              "keras.applications.EfficientNetV2L")
 def EfficientNetV2L(
     include_top=True,
     weights="imagenet",
@@ -1244,8 +1243,7 @@ EfficientNetV2M.__doc__ = BASE_DOCSTRING.format(name="EfficientNetV2M")
 EfficientNetV2L.__doc__ = BASE_DOCSTRING.format(name="EfficientNetV2L")
 
 
-@keras_export("keras.applications.efficientnet_v2.preprocess_input")
-def preprocess_input(x, data_format=None):  # pylint: disable=unused-argument
+def preprocess_input(x, data_format=None, **kwargs):  # pylint: disable=unused-argument
     """A placeholder method for backward compatibility.
 
     The preprocessing logic has been included in the EfficientNetV2 model
@@ -1266,8 +1264,7 @@ def preprocess_input(x, data_format=None):  # pylint: disable=unused-argument
     return x
 
 
-@keras_export("keras.applications.efficientnet_v2.decode_predictions")
-def decode_predictions(preds, top=5):
+def decode_predictions(preds, top=5, **kwargs):
     return imagenet_utils.decode_predictions(preds, top=top)
 
 
