@@ -196,6 +196,7 @@ def ResNet(
         init_filters=64,
         first_kernel_size=49,
         repetitions=None,
+        pooling=None,
         **kwargs
 ):
     """Instantiates the ResNet, SEResNet architecture.
@@ -323,6 +324,11 @@ def ResNet(
         x = layers.GlobalAveragePooling1D(name='pool1')(x)
         x = layers.Dense(classes, name='fc1')(x)
         x = layers.Activation('softmax', name='softmax')(x)
+    else:
+        if pooling == 'avg':
+            x = layers.GlobalAveragePooling1D(name='avg_pool')(x)
+        elif pooling == 'max':
+            x = layers.GlobalMaxPooling1D(name='max_pool')(x)
 
     # Ensure that the model takes into account any potential predecessors of `input_tensor`.
     if input_tensor is not None:
@@ -337,7 +343,16 @@ def ResNet(
         if type(weights) == str and os.path.exists(weights):
             model.load_weights(weights)
         else:
-            load_model_weights(model, model_params.model_name, weights, classes, include_top, **kwargs)
+            load_model_weights(
+                model,
+                model_params.model_name,
+                weights,
+                classes,
+                include_top,
+                kernel_size,
+                input_shape[-1],
+                **kwargs
+            )
 
     return model
 
@@ -361,6 +376,7 @@ def ResNet18(
         input_shape=None,
         input_tensor=None,
         weights=None,
+        pooling=None,
         classes=1000,
         include_top=True,
         stride_size=4,
@@ -375,6 +391,7 @@ def ResNet18(
         include_top=include_top,
         classes=classes,
         weights=weights,
+        pooling=pooling,
         stride_size=stride_size,
         kernel_size=kernel_size,
         repetitions=repetitions,
@@ -386,6 +403,7 @@ def ResNet34(
         input_shape=None,
         input_tensor=None,
         weights=None,
+        pooling=None,
         classes=1000,
         include_top=True,
         stride_size=4,
@@ -400,6 +418,7 @@ def ResNet34(
         include_top=include_top,
         classes=classes,
         weights=weights,
+        pooling=pooling,
         stride_size=stride_size,
         kernel_size=kernel_size,
         repetitions=repetitions,
@@ -411,6 +430,7 @@ def ResNet50(
         input_shape=None,
         input_tensor=None,
         weights=None,
+        pooling=None,
         classes=1000,
         include_top=True,
         stride_size=4,
@@ -425,6 +445,7 @@ def ResNet50(
         include_top=include_top,
         classes=classes,
         weights=weights,
+        pooling=pooling,
         stride_size=stride_size,
         kernel_size=kernel_size,
         repetitions=repetitions,
@@ -436,6 +457,7 @@ def ResNet101(
         input_shape=None,
         input_tensor=None,
         weights=None,
+        pooling=None,
         classes=1000,
         include_top=True,
         stride_size=4,
@@ -450,6 +472,7 @@ def ResNet101(
         include_top=include_top,
         classes=classes,
         weights=weights,
+        pooling=pooling,
         stride_size=stride_size,
         kernel_size=kernel_size,
         repetitions=repetitions,
@@ -461,6 +484,7 @@ def ResNet152(
         input_shape=None,
         input_tensor=None,
         weights=None,
+        pooling=None,
         classes=1000,
         include_top=True,
         stride_size=4,
@@ -475,6 +499,7 @@ def ResNet152(
         include_top=include_top,
         classes=classes,
         weights=weights,
+        pooling=pooling,
         stride_size=stride_size,
         kernel_size=kernel_size,
         repetitions=repetitions,
@@ -486,6 +511,7 @@ def SEResNet18(
         input_shape=None,
         input_tensor=None,
         weights=None,
+        pooling=None,
         classes=1000,
         include_top=True,
         stride_size=4,
@@ -500,6 +526,7 @@ def SEResNet18(
         include_top=include_top,
         classes=classes,
         weights=weights,
+        pooling=pooling,
         stride_size=stride_size,
         kernel_size=kernel_size,
         repetitions=repetitions,
@@ -511,6 +538,7 @@ def SEResNet34(
         input_shape=None,
         input_tensor=None,
         weights=None,
+        pooling=None,
         classes=1000,
         include_top=True,
         stride_size=4,
@@ -525,6 +553,7 @@ def SEResNet34(
         include_top=include_top,
         classes=classes,
         weights=weights,
+        pooling=pooling,
         stride_size=stride_size,
         kernel_size=kernel_size,
         repetitions=repetitions,
