@@ -379,7 +379,16 @@ def SENet(
         if type(weights) == str and os.path.exists(weights):
             model.load_weights(weights)
         else:
-            load_model_weights(model, model_params.model_name, weights, classes, include_top, **kwargs)
+            load_model_weights(
+                model,
+                model_params.model_name,
+                weights,
+                classes,
+                include_top,
+                kernel_size,
+                input_shape[-1],
+                **kwargs
+            )
 
     return model
 
